@@ -1,7 +1,7 @@
 package B::Lint;
 use if $] > 5.017, 'deprecate';
 
-our $VERSION = '1.22';    ## no critic
+our $VERSION = '1.23';    ## no critic
 
 =head1 NAME
 
@@ -160,7 +160,7 @@ the current filename and line number.
   package Sample;
   use B::Lint;
   B::Lint->register_plugin( Sample => [ 'good_taste' ] );
-  
+
   sub match {
       my ( $op, $checks_href ) = shift @_;
       if ( $checks_href->{good_taste} ) {
@@ -193,6 +193,12 @@ Malcolm Beattie, mbeattie@sable.ox.ac.uk.
 =head1 ACKNOWLEDGEMENTS
 
 Sebastien Aperghis-Tramoni - bug fixes
+Joshua ben Jore - old maintainer
+Reini Urban - maintainer
+
+Co-maintainers:
+
+ASH, CLKAO, FLORA, GRUBER, JCROMIE, NWCLARK, RJBS
 
 =cut
 
